#
# spec file for package nvidia-settings
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
# or the Packman mailing list


Name:           nvidia-settings
Version:        325.15
Release:        1.2
Summary:        Configuration Tool for NVIDIA GPUs
License:        GPL-2.0
Group:          System/X11/Utilities
Url:            ftp://download.nvidia.com/XFree86/Linux-x86/%{version}/README/index.html
Source:         ftp://download.nvidia.com/XFree86/nvidia-settings/nvidia-settings-%{version}.tar.bz2
Source1:        nvidia-settings.desktop
Source99:       %{name}-rpmlintrc
# Package was branched from home:malcolmlewis
# PATCH-FIX-PACKMAN nvidia-settings-optflags.patch malcolmlewis@opensuse.org -- Rebase patch as only need optflags now.
Patch1:         nvidia-settings-optflags.patch
BuildRequires:  Mesa
BuildRequires:  Mesa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  libvdpau-devel
BuildRequires:  make
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The nvidia-settings utility is a tool for configuring the NVIDIA Linux
graphics driver. It operates by communicating with the NVIDIA X driver,
querying and updating state as appropriate. This communication is done with
the NV-CONTROL X extension.

Values such as brightness and gamma, XVideo attributes, temperature, and
OpenGL settings can be queried and configured via nvidia-settings.

When nvidia-settings starts, it reads the current settings from its
configuration file and sends those settings to the X server.
Then, it displays a graphical user interface (GUI) interface for configuring
the current settings. When nvidia-settings exits, it queries the current
settings from the X server and saves them to the configuration file.

%package -n libXNVCtrl
Summary:        NVidia Control Library
Group:          Development/Libraries/C and C++

%description -n libXNVCtrl
Library for configuring the NVIDIA Linux graphics driver. It operates by
communicating with the NVIDIA X driver, querying and updating state as
appropriate. This communication is done with the NV-CONTROL X extension.

%prep
%setup -q -n "nvidia-settings-%{version}"
%patch1 -p1

%build
SUBS="src/libXNVCtrl ."
for d in $SUBS; do
    make -C "$d" clean
done
for d in $SUBS; do
    make %{?_smp_mflags} \
    	  CC="gcc" \
    	  X11R6_DIR="%{_prefix}" \
    	  X11_LIB_DIRS="-L%{_libdir}" \
    	  X11_INC_DIRS="-I%{_includedir}" \
    	  STRIP=touch \
    	  INSTALL="install" \
          NV_VERBOSE=1 \
	  OPTFLAGS="%{optflags}" \
    	  -C "$d"
done

%install
install -d "%{buildroot}%{_bindir}"
make \
    	  STRIP=touch \
    	  INSTALL="install" \
          bindir="%{buildroot}%{_bindir}" \
          mandir="%{buildroot}%{_mandir}/man1" \
	  PREFIX="%{buildroot}%{_prefix}" \
          install

rm -f \
    "%{buildroot}%{_bindir}"/*.h \
    "%{buildroot}%{_bindir}"/*.mk

for g in "%{buildroot}%{_mandir}"/man*/*.gz; do
    gzip -d "$g"
done

chmod 0644 "%{buildroot}%{_mandir}"/man*/*.*

install -d "%{buildroot}%{_libdir}"
install -m0644 src/libXNVCtrl/libXNVCtrl.a "%{buildroot}%{_libdir}/"
install -d "%{buildroot}%{_includedir}/NVCtrl"
install -m0644 src/libXNVCtrl/*.h "%{buildroot}%{_includedir}/NVCtrl/"

install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" System HardwareSettings

%files
%defattr(-,root,root)
%doc COPYING doc/*.txt
%{_bindir}/nvidia-settings
%{_datadir}/applications/%{name}.desktop
%doc %{_mandir}/man1/nvidia-settings.1%{ext_man}

%files -n libXNVCtrl
%defattr(-,root,root)
%{_includedir}/NVCtrl
%{_libdir}/libXNVCtrl.a

%changelog
* Tue Aug 13 2013 musicsuse@gmx.com
- Update to version 325.15
  * Updated build requirements to include libvdpau-devel
* Tue Feb 14 2012 herbert@links2linux.de
- update to 290.10
* Sat Feb 26 2011 pascal.bleser@opensuse.org
- update to 270.29
* Sat Dec  4 2010 pascal.bleser@opensuse.org
- update to 260.19.21
* Mon Jul 19 2010 pascal.bleser@opensuse.org
- update to 256.35
* Sun Feb  7 2010 detlef@links2linux.de
- update to 190.53
* Wed Sep 30 2009 pascal.bleser@opensuse.org
- update to 190.36
* Sun May  3 2009 pascal.bleser@opensuse.org
- update to 185.19
* Wed Jul 23 2008 guru@unixtech.be
- new package
